==> vertx-lang-kotlin-4.5.11-sources.jar: io/vertx/kotlin/redis/client/RedisReplicationConnectOptions.kt <==
/*
 * Copyright 2019 Red Hat, Inc.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * and Apache License v2.0 which accompanies this distribution.
 *
 * The Eclipse Public License is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * The Apache License v2.0 is available at
 * http://www.opensource.org/licenses/apache2.0.php
 *
 * You may elect to redistribute this code under either of these licenses.
 */
package io.vertx.kotlin.redis.client

import io.vertx.redis.client.RedisReplicationConnectOptions
import io.vertx.redis.client.ProtocolVersion
import io.vertx.redis.client.RedisReplicas
import io.vertx.redis.client.RedisTopology

fun redisReplicationConnectOptionsOf(
  connectionString: String? = null,
  connectionStrings: Iterable<String>? = null,
  endpoints: Iterable<String>? = null,
  maxNestedArrays: Int? = null,
  maxWaitingHandlers: Int? = null,
  password: String? = null,
  preferredProtocolVersion: ProtocolVersion? = null,
  protocolNegotiation: Boolean? = null,
  topology: RedisTopology? = null,
  useReplicas: RedisReplicas? = null): RedisReplicationConnectOptions = io.vertx.redis.client.RedisReplicationConnectOptions().apply {

  if (connectionString != null) {
    this.setConnectionString(connectionString)
  }
  if (connectionStrings != null) {
    for (item in connectionStrings) {
      this.addConnectionString(item)
    }
  }
  if (endpoints != null) {
    this.setEndpoints(endpoints.toList())
  }
  if (maxNestedArrays != null) {
    this.setMaxNestedArrays(maxNestedArrays)
  }
  if (maxWaitingHandlers != null) {
    this.setMaxWaitingHandlers(maxWaitingHandlers)
  }
  if (password != null) {
    this.setPassword(password)
  }
  if (preferredProtocolVersion != null) {
    this.setPreferredProtocolVersion(preferredProtocolVersion)
  }
  if (protocolNegotiation != null) {
    this.setProtocolNegotiation(protocolNegotiation)
  }
  if (topology != null) {
    this.setTopology(topology)
  }
  if (useReplicas != null) {
    this.setUseReplicas(useReplicas)
  }
}

==> vertx-lang-kotlin-5.0.1-sources.jar: io/vertx/kotlin/redis/client/RedisReplicationConnectOptions.kt <==
/*
 * Copyright 2019 Red Hat, Inc.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * and Apache License v2.0 which accompanies this distribution.
 *
 * The Eclipse Public License is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * The Apache License v2.0 is available at
 * http://www.opensource.org/licenses/apache2.0.php
 *
 * You may elect to redistribute this code under either of these licenses.
 */
package io.vertx.kotlin.redis.client

import io.vertx.redis.client.RedisReplicationConnectOptions
import io.vertx.redis.client.ProtocolVersion
import io.vertx.redis.client.RedisReplicas
import io.vertx.redis.client.RedisTopology

fun redisReplicationConnectOptionsOf(
  maxNestedArrays: Int? = null,
  protocolNegotiation: Boolean? = null,
  preferredProtocolVersion: ProtocolVersion? = null,
  user: String? = null,
  password: String? = null,
  endpoints: Iterable<String>? = null,
  maxWaitingHandlers: Int? = null,
  topology: RedisTopology? = null,
  useReplicas: RedisReplicas? = null,
  connectionStrings: Iterable<String>? = null,
  connectionString: String? = null): RedisReplicationConnectOptions = io.vertx.redis.client.RedisReplicationConnectOptions().apply {

  if (maxNestedArrays != null) {
    this.setMaxNestedArrays(maxNestedArrays)
  }
  if (protocolNegotiation != null) {
    this.setProtocolNegotiation(protocolNegotiation)
  }
  if (preferredProtocolVersion != null) {
    this.setPreferredProtocolVersion(preferredProtocolVersion)
  }
  if (user != null) {
    this.setUser(user)
  }
  if (password != null) {
    this.setPassword(password)
  }
  if (endpoints != null) {
    this.setEndpoints(endpoints.toList())
  }
  if (maxWaitingHandlers != null) {
    this.setMaxWaitingHandlers(maxWaitingHandlers)
  }
  if (topology != null) {
    this.setTopology(topology)
  }
  if (useReplicas != null) {
    this.setUseReplicas(useReplicas)
  }
  if (connectionStrings != null) {
    for (item in connectionStrings) {
      this.addConnectionString(item)
    }
  }
  if (connectionString != null) {
    this.setConnectionString(connectionString)
  }
}
